@@ -1,15 +1,21 @@
 from niaaml.utilities import ParameterDefinition, MinMax
-from niaaml.preprocessing.feature_selection.feature_selection_algorithm import FeatureSelectionAlgorithm
-from sklearn.feature_selection import SelectKBest as SelectKB, chi2
+from niaaml.preprocessing.feature_selection.feature_selection_algorithm import (
+    FeatureSelectionAlgorithm,
+)
+from sklearn.feature_selection import (
+    SelectKBest as SelectKB,
+    chi2,
+    f_classif,
+    mutual_info_classif,
+)
 import numpy as np
 
-__all__ = [
-    'SelectKBest'
-]
+__all__ = ["SelectKBest"]
+
 
 class SelectKBest(FeatureSelectionAlgorithm):
     r"""Implementation of feature selection using selection of k best features according to used score function.
-    
+
     Date:
         2020
 
@@ -18,14 +24,14 @@ class SelectKBest(FeatureSelectionAlgorithm):
 
     License:
         MIT
-    
+
     Documentation:
         https://scikit-learn.org/stable/modules/generated/sklearn.feature_selection.SelectKBest.html
-    
+
     See Also:
         * :class:`niaaml.preprocessing.feature_selection.feature_selection_algorithm.FeatureSelectionAlgorithm`
     """
-    Name = 'Select K Best'
+    Name = "Select K Best"
 
     def __init__(self, **kwargs):
         r"""Initialize SelectKBest feature selection algorithm.
@@ -34,17 +40,16 @@ class SelectKBest(FeatureSelectionAlgorithm):
             _params['k'] is initialized to None as it is included in the optimization process later since we cannot determine a proper value range until length of the feature vector becomes known.
         """
         self._params = dict(
-            score_func = ParameterDefinition([chi2]),
-            k = None
+            score_func=ParameterDefinition([chi2, f_classif, mutual_info_classif]),
+            k=None,
         )
         self.__k = None
         self.__select_k_best = SelectKB()
-    
+
     def set_parameters(self, **kwargs):
-        r"""Set the parameters/arguments of the algorithm.
-        """
+        r"""Set the parameters/arguments of the algorithm."""
         self.__select_k_best.set_params(**kwargs)
-    
+
     def select_features(self, x, y, **kwargs):
         r"""Perform the feature selection process.
 
@@ -57,10 +62,10 @@ class SelectKBest(FeatureSelectionAlgorithm):
         """
         if self.__k is None:
             self.__k = x.shape[1]
-            self._params['k'] = ParameterDefinition(MinMax(1, self.__k), np.int)
+            self._params["k"] = ParameterDefinition(MinMax(1, self.__k), np.int)
             val = np.int(np.around(np.random.uniform(1, self.__k)))
             self.__select_k_best.set_params(k=val)
-        
+
         self.__select_k_best.fit(x, y)
         return self.__select_k_best.get_support()
 
@@ -70,4 +75,7 @@ class SelectKBest(FeatureSelectionAlgorithm):
         Returns:
             str: User friendly representation of the object.
         """
-        return FeatureSelectionAlgorithm.to_string(self).format(name=self.Name, args=self._parameters_to_string(self.__select_k_best.get_params()))
\ No newline at end of file
+        return FeatureSelectionAlgorithm.to_string(self).format(
+            name=self.Name,
+            args=self._parameters_to_string(self.__select_k_best.get_params()),
+        )
