@@ -3,9 +3,4 @@ from niaaml.preprocessing.imputation.simple_imputer import SimpleImputer
 from niaaml.preprocessing.imputation.utility import ImputerFactory
 from niaaml.preprocessing.imputation.utility import impute_features
 
-__all__ = [
-    'Imputer',
-    'SimpleImputer',
-    'ImputerFactory',
-    'impute_features'
-]
\ No newline at end of file
+__all__ = ["Imputer", "SimpleImputer", "ImputerFactory", "impute_features"]
