@@ -1,19 +1,20 @@
 from unittest import TestCase
 from niaaml.preprocessing.encoding import EncoderFactory, FeatureEncoder
 
+
 class FitnessFactoryTestCase(TestCase):
     def setUp(self):
         self.__factory = EncoderFactory()
-    
+
     def test_get_result_works_fine(self):
         for entry in self.__factory._entities:
             instance = self.__factory.get_result(entry)
             self.assertIsNotNone(instance)
             self.assertIsInstance(instance, FeatureEncoder)
-        
+
         with self.assertRaises(TypeError):
-            self.__factory.get_result('non_existent_name')
-    
+            self.__factory.get_result("non_existent_name")
+
     def test_get_dictionary_works_fine(self):
         d = self.__factory.get_name_to_classname_mapping()
         d_keys = d.keys()
@@ -22,4 +23,4 @@ class FitnessFactoryTestCase(TestCase):
         self.assertEqual(len(e_keys), len(d_keys))
 
         for k in d:
-            self.assertIsNotNone(d[k])
\ No newline at end of file
+            self.assertIsNotNone(d[k])
